/*********************************************************************
 * libaeon - A simple, lightweight, cross platform networking library
 * Copyright 2006-2007 (c) Elden Armbrust
 * This software is licensed under the BSD software license.
 *
 * libaeon documentation include
 *********************************************************************/

//main page menu/links
/**
  \mainpage libaeon Documentation
  \section info Information
  \li \ref license
  \section intro_sec Getting Started
  \subsection installing Installing
  \li \ref obtain
  \li \ref unpack
  \li \ref build
*/



//Install instructions
/**
  \page obtain Obtaining
  \section obtaining Obtaining the source code
  There are two ways to download the source code to libaeon.

  \subsection sfnetdl Downloading from sourceforge.net
  The first way, and most common, is to download a source tarball from
  a sourceforge mirror.  This is the easiest, and most stable, method
  for implementing libaeon.  However, you may not see the most recent
  changes to the library in a source tarball.  That aside, source
  tarballs are generally considered more stable than other methods.

  <em>To download libaeon, visit http://libaeon.sourceforge.net/</em>

  \subsection sfnightly Downloading nightly tarballs
  Another common way to obtain libaeon is through nightly tarball
  releases.  These are more up to date (generally) than the release
  tarballs, but are done automatically, which means that the code may
  or may not work properly.

  <em>Visit http://libaeon.sourceforge.net/download.html to download
  a nightly tarball.</em>

  Continue to \ref unpack
 */



/**
  \page unpack Unpacking
  \section unpack Unpacking the source
  Depending on your distribution/OS, unpacking the source distribution may vary.

  \subsection tarbz2 Unpacking from a bzipped tarball
  If you downloaded the gzipped tarball (.tar.gz) then you will most likely
  want to extract the file as such:
  \code
  tar -xvjf libaeon-x.xx.xx.tar.bz2
  \endcode
  \subsection targz Unpacking from a gzipped tarball
  If you downloaded the gzipped tarball (.tar.gz) then you will most likely
  want to extract the file as such:
  \code
  tar -xvzf libaeon-x.xx.xx.tar.gz
  \endcode
  \subsection zip Unpacking from a zipped file set
  If you downloaded the zipped fileset (.zip) then you will most likely
  want to extract the file as such:
  \code
  unzip libaeon-x.xx.xx.zip
  \endcode

  Back to \ref obtain

  Continue to \ref build
*/


/**
  \page build Building
  \section preconfigure Generating the configure script
  If you have downloaded the source from the CVS or SVN repositories, then
  you should first create the necessary files by using autotools, or by
  using the included autogen.sh script.
  To do so, simply change directories to the source tree and run the script
  as such:
  \code
  cd ./libaeon-0.16.15/
  ./autogen.sh
  \endcode

  \section configure Configuring for building
  Before building the library, you must configure it to work on your
  system.  To do so, you must run the configure script that was either
  included in your package, or built by the autogen script.

  To configure the source code for compilation, run the script as so:
  \code
  ./configure
  \endcode

  \section compile Compiling the library
  Once you have completed running the configure script, it's time to
  compile the code.  On most Linux/UNIX systems, it would simply be:
  \code
  make
  \endcode

  This should compile the code into a library file, ready for use.
  To install the library system-wide afer compilation, you should use:
  \code
  make install
  \endcode

*/


/**
  \page license License
  \verbatim
libaeon License (BSD License)
Copyright (c) 2006-2007, Elden Armbrust
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are
met:

    * Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
    * Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in
      the documentation and/or other materials provided with the
      distribution.
    * Neither the name of libaeon nor the names of its
      contributors may be used to endorse or promote products derived
      from this software without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
"AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  \endverbatim
*/


